import  { CommonSDK }  from './common'
import { asyncLoadJs } from '../utils/load'
import { getLocal, removeLocal } from '../utils/storage'
import { getQueryString } from '../utils/url-params'

asyncLoadJs('https://appx/web-view.min.js')

class AlipaySDK extends CommonSDK {
	static getInstance () {
		if (!this.instance) {
			this.instance = new AlipaySDK()
		}
		return this.instance
	}

    gotoHomePage (url = '/pages/index/index') {
		// eslint-disable-next-line no-undef
		my && my.switchTab({ url: url })
	}
	/**
	 * 支付
	 * @param {*} params 支付需要参数 接口返回
	 *  第二个参数对象为  自定义参数
	 *  callbackUrl 支付成功跳转地址 完整地址 https:xxx.xxx.xx/#/xx 非app
	 *  failBackUrl 支付失败 跳转页面 非app
	 *  orderTitle  支付订单类型
	 *  callback, remark 游上海sdk支付需要， 其他方式不需要
	 * 	wxSource 小程序 支付source 由小程序开发人员确定
	 * 	token 登录凭证 h5支付, 微信小程序需要
	 *
	 */
	openOrderPay (params, {callbackUrl = '',  wxSource='JinJiangHotel', failBackUrl = ''}) {
		failBackUrl = failBackUrl || callbackUrl
		let {token,amount, orderTitle} = params
		let wxPayParams = {
			token,
			amount,
			orderTitle:orderTitle
		}
		my && my.redirectTo({
			url: `/pages/pay/pay?source=${encodeURIComponent(wxSource)}&successBackUrl=${encodeURIComponent(callbackUrl)}&failBackUrl=${encodeURIComponent(failBackUrl)}&payParams=${encodeURIComponent(JSON.stringify(wxPayParams))}`
		})
	}

	/**
	 * 唤起登录
	 * @param {*} yshparams  原生sdk 所需参数
	 * @param {*} otherTypeParam 其他登录方式所需参数
	 * @param {String} tokenKey 存取token的key
	 */
	callAppLogin (yshparams = {}, otherTypeParam = {}, tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			const token = getLocal(tokenKey) || ''
			let {notCallLogin} = yshparams
			if (notCallLogin) {
				const oMember = {
					token: token
				}
				resolve(oMember)
			} else {
				let {backUrl, type,miniLoginUrl} = otherTypeParam
				let {latestUtm} = yshparams
				otherTypeParam.backUrl = encodeURIComponent(backUrl || window.location.href)
				otherTypeParam.type = type|| 'h5'
				if (latestUtm) {
					otherTypeParam.latestUtm = latestUtm
				}
				miniLoginUrl = miniLoginUrl || '/pages/login/login'
				let paraString = getQueryString(otherTypeParam)
				paraString = paraString ? `?${paraString}` : ''
				// eslint-disable-next-line no-undef
				my && my.redirectTo({
					url: `${miniLoginUrl}${paraString}`
				})
			}
		})
	}
}

export  { AlipaySDK }
