
import { getLocal, setLocal, removeLocal } from '../utils/storage'
import native, { passiveNative } from './lib/native'
import { getHost } from '../utils/host'

class CommonSDK {
	constructor () {
		this._generateApi()
		this.phoneLink = null
	}

	static getInstance (name) {
		if (!this.instance) {
			this.instance = new CommonSDK()
		}
		return this.instance
	}

	_generateApi () {
		let names = Object.keys(native)
		names = names.concat(Object.keys(passiveNative))
		names.forEach(name => {
			// 申明过的api，不在处理
			if (this[name]) return
			// eslint-disable-next-line no-proto
			this.__proto__[name] = (data) => {
				return new Promise((resolve, reject) => {
					resolve()
				})
			}
		})
	}
	/**
	 * 打开新的WebView加载页面
	 * @param {*} param0 {
	 * 	url:跳转地址
	 * 	isthirdUrl: 是否是第三方地址
	 *  isMiniprogam： 是否在小程序中
	 * 	routeUrl  路由跳转 url
	 * }
	 * @param {*} gotoHome
	 */
	openNewWebView ({ url = '', isthirdUrl = false, isMiniprogam = false, vmRouter, routeUrl = '' }, gotoHome) {
		return new Promise((resolve, reject) => {
			url = url.trim()
			routeUrl = routeUrl.trim()
			if (isMiniprogam && isthirdUrl) {
				resolve({
					result: 'noSupport',
					des: 'Third url are not supported in miniprogam'
				})
				return true
			}
			if (routeUrl && vmRouter) {
				vmRouter.push(routeUrl)
			} else {
				location.href = url
			}
		})
	}
	/**
	 * 支付
	 * @param {*} params 支付需要参数 接口返回
	 *  第二个参数对象为  自定义参数
	 *  callbackUrl 支付成功跳转地址 完整地址 https:xxx.xxx.xx/#/xx 非app
	 *  failBackUrl 支付失败 跳转页面 非app
	 *  orderTitle  支付订单类型
	 *  callback, remark 游上海sdk支付需要， 其他方式不需要
	 * 	wxSource 小程序 支付source 由小程序开发人员确定
	 * 	token 登录凭证 h5支付, 微信小程序需要
	 * appEnv  h5 支付环境
	 *
	 */
	openOrderPay (params, { callbackUrl = '', failBackUrl = '', token = '', appEnv }) {
		let { orderTitle } = params
		const hostUrl = `${getHost(appEnv).JJ_ONLINE_HOME}/toolpage/wepay.html`
		window.location.href = `${hostUrl}?token=${token}&paytoken=${params.token}&amount=${params.amount}&title=${encodeURIComponent(orderTitle)}&callbackUrl=${encodeURIComponent(encodeURIComponent(failBackUrl))}&payurl=${encodeURIComponent(encodeURIComponent(callbackUrl))}`
	}
	// 设置标题
	setAppTitle (params) {
		const defaultOpt = {
			showLeftBT: true,
			showRightBT: false,
			showRightBTText: '',
			title: '',
			showTitle: true,
			transparent: false,
			showLine: false,
			suspension: false,
			setStatusBarBlackType: true
		}

		for (const i in params) {
			defaultOpt[i] = params[i]
		}
		window.document.title = defaultOpt.title
		// setTitleAndTrack(defaultOpt.title ? defaultOpt.title : '游上海')
	}

	// 关闭当前webview
	closeWebView () {
		history.go(-1)
	}

	// 监听返回
	watchAppBackBtn (handle) {
	}
	watchRightBtn () { }

	refreshPage () { }
	share () { }

	// 页面将要展示
	viewWillAppear () { }

	// 页面将要离开
	viewWillDisappear () { }

	// 获取当前用户位置
	gainLocation (vm) {
		return new Promise((resolve, reject) => {
			const oData = {
				// msgCode: 100,
				// message: 'success',
				// result: {
				address: '上海市黄浦区南京东路街道国际饭店',
				city: '上海',
				cityId: '',
				district: '黄浦区',
				gdLatitude: getLocal('latitude') || '31.233735',
				gdLongitude: getLocal('longitude') || '121.471625',
				isDefaultInfo: !(getLocal('latitude') && getLocal('longitude'))
				// }
			}
			resolve(oData)
		})
	}

	// loading
	showLoading () {
	}
	hideLoading () {
	}
	// 拨打电话
	callPhone (params) {
		let data = params || {}
		let phone = data.phoneNumber || ''

		if (!this.phoneLink) {
			this.phoneLink = document.createElement('a')
		}
		if (phone) {
			this.phoneLink.setAttribute('href', `tel:${phone}`)
			this.phoneLink.click()
		}
	}
	// 打开视频
	openVideo (params) {
	}
	// 点击图片放大功能
	openImageSwitcher (options) {
	}
	getMemCacheKeyValue (params) {
		return new Promise((resolve, reject) => {
			const val = getLocal(params.keyName)
			resolve({
				valueContent: val
			})
		})
	}

	setMemCacheKeyValue (params) {
		return new Promise((resolve, reject) => {
			setLocal(params.keyName, params.valueContent)
			resolve()
		})
	}

	/**
	 * 唤起登录
	 * @param {*} yshparams  原生sdk 所需参数
	 * @param {*} otherTypeParam 其他登录方式所需参数  appEnv 登录对应环境的地址
	 * @param {String} tokenKey 存取token的key
	 */
	callAppLogin (yshparams = {}, otherTypeParam = {}, tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			let { notCallLogin } = yshparams
			let token = getLocal(tokenKey) || ''
			if (notCallLogin) {
				const oMember = {
					token: token
				}
				resolve(oMember)
			} else {
				let { appEnv, backUrl } = otherTypeParam
				backUrl = encodeURIComponent(backUrl || location.href)
				location.href = `${getHost(appEnv)}/tool-page/login.html?redirect=${backUrl}`
			}
		})
	}

	// 获取原生存储
	getStore ({ keyName }) {
		return new Promise((resolve, reject) => {
			const valueC = localStorage.getItem(keyName) || ''
			resolve({
				valueContent: valueC
			})
		})
	}

	// 设置原生存储
	setStore ({ keyName, valueContent }, callback) {
		return new Promise((resolve, reject) => {
			localStorage.setItem(keyName, valueContent)
			resolve()
		})
	}

	// 从浏览器打开
	openBrowser (params) {
		const url = params.url.trim()
		location.href = url
	}
}

export { CommonSDK }
