/**
 *    公共SDK方法
 *
 */
import WeSDK from './lib/sdk'
import native, { passiveNative } from './lib/native'

WeSDK.setAppKey('95b04967d08c42ad91b1d56ad7e7536a')

const setWeHotel = (callback) => {
	WeSDK.ready(() => {
		callback && callback()
	})
}

class JinjiangOnlineSDK {
	static getInstance () {
		if (!this.instance) {
			this.instance = new JinjiangOnlineSDK()
		}
		return this.instance
	}

	constructor () {
		this.appVersion = WeSDK.appVersion
		this.shortAppVersion = WeSDK.shortAppVersion
		this.isIOS = WeSDK.isIOS
		this.channelCode = this.isIOS ? '10017' : '10009'
		this.refreshPageCallbacks = []
		this.refreshRegistered = false
		this.rightBtnCallbacks = []
		this.rightBtnRegistered = false
    this.disableOpenWebview = false
    this.viewWillAppearCallbacks = []
		this.viewWillAppearRegistered = false
		this.viewWillDisappearCallbacks = []
		this.viewWillDisappearRegistered = false
		this._passiveApi()
		this._generateApi() // 手动触发
	}

	_generateApi () {
		// 对应api名称 http://gzgit.bestwehotel.com/app-javascript/utils/blob/develop/src/wehotel.sdk.js 171行
		const names = Object.keys(native)
		names.forEach(name => {
			// 申明过的api，不在处理
			if (this[name]) return
			this[name] = (data) => {
				return new Promise((resolve, reject) => {
					setWeHotel(() => {
						console.log('appdata--->', data)
						console.log('name--->', name)
						console.log('sdk[name]--->', WeSDK[name])
						WeSDK[name]({
							data: data || {},
							success (res) { // 有些api没有success回调，有些api在ios和android上也有区别
								if (res.msgCode === 100 || res.result === true) {
									resolve(res.result)
								} else {
									reject(res)
								}
							}
						})
					})
				})
			}
		})
	}

	_passiveApi () {
		Object.keys(passiveNative).forEach(name => {
			// 申明过的api，不在处理
			if (this[name]) return
			this[name] = (data) => {
				return new Promise((resolve, reject) => {
					setWeHotel(() => {
						WeSDK.registerHandler(passiveNative[name], () => {
							resolve()
						})
					})
				})
			}
		})
	}

	  // 获取当前用户位置
	gainLocation (params = {}) {
		const defaultOpt = {
			forceUpdate: false
		}
		for (const i in params) {
			defaultOpt[i] = params[i]
		}
		return new Promise((resolve, reject) => {
			WeSDK.ready(_ => {
				WeSDK.gainLocation({
					data: defaultOpt,
					success: (res) => {
						if (res.msgCode === 100 || res.result === true) {
							resolve(res.result)
						} else {
							let result = {
								gdLatitude: '31.233735',
								gdLongitude: '121.471625',
								isDefaultInfo: true
							}
							resolve(result)
						}
					}
				})
			})
		})
	}

	// 设置标题
	setAppTitle (params) {
		/**
		 * @param { Number } showRightBTImage
		 * 2：导航栏右侧按钮    分享
		 * 3：导航栏右侧按钮    地图
		 * 4：导航栏右侧按钮    未收藏 分享
		 * 5：导航栏右侧按钮    已收藏 分享
		 * 6：导航栏右侧按钮    未收藏
		 * 7：导航栏右侧按钮    已收藏
		 */
		const defaultOpt = {
			showLeftBT: true,
			showRightBT: false,
			showRightBTText: '',
			title: '',
			showTitle: true,
			transparent: false,
			showLine: false,
			suspension: false,
			setStatusBarBlackType: true
		}

		for (const i in params) {
			defaultOpt[i] = params[i]
		}

		setWeHotel(() => {
			WeSDK.initTitle({
				data: defaultOpt,
				success: () => {
				}
			})
		})
		// setTitleAndTrack(params.title)
	}

	// 监听收藏、分享
	watchRightBtn (handle) {
		if (this.rightBtnRegistered) {
			this.rightBtnCallbacks.push(handle)
		} else {
			setWeHotel(() => {
				this.rightBtnCallbacks.push(handle)
				this.rightBtnRegistered = true
				/**
				 * @param { Object } result
				 * @example
				 * result = {
				 * 		message: "success",
				 * 		msgCode: 100,
				 * 		result: "0"	// 右起第几个按钮
				 * }
				 */
				WeSDK.registerHandler('BTTitlePlugin/clickRightBT', result => {
					for (const func of this.rightBtnCallbacks) {
						if (typeof func === 'function') {
							func(result)
						}
					}
				})
			})
		}
	}
	// 监听返回
	watchAppBackBtn (handle) {
		setWeHotel(() => {
			WeSDK.registerHandler('BTTitlePlugin/clickLeftBT', () => {
				handle && handle()
			})
		})
	}

	// 打开新的WebView加载页面
	openNewWebView ({ url, isFitWindow = true, isShowLoading = true, isNeedBindNFCService = false }, gotoHome) {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				url = url.trim()
				WeSDK.openNewWebView({
					data: {
						url: url,
						isFitWindow: isFitWindow,
						isShowLoading: isShowLoading,
						gotoHomepage: gotoHome,
						isNeedBindNFCService: isNeedBindNFCService
					},
					success: () => {
						resolve()
					}
				})
			})
		})
	}

	callThirdLogin (params, tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.thirdLogin({
					data: params,
					success: (data) => {
						let token = ''
						if (data.msgCode === 100) {
							if (typeof data.result === 'string') {
								const b = JSON.parse(data.result)
								token = b.token
							} else if (Object.keys(data.result).length === 0) {
								token = ''
							} else {
								token = data.result.token
							}
							window.localStorage.setItem(tokenKey, token)
							resolve(data.result)
						} else {
							reject(data)
						}
					}
				})
			})
		})
	}

	/**
	 * 支付
	 * @param {*} params 支付需要参数 接口返回
	 *  第二个参数对象为  自定义参数
	 *  callbackUrl 支付成功跳转地址 完整地址 https:xxx.xxx.xx/#/xx 非app
	 *  failBackUrl 支付失败 跳转页面 非app
	 *  orderTitle  支付订单类型
	 *  callback, remark 游上海sdk支付需要， 其他方式不需要
	 * 	wxSource 小程序 支付source 由小程序开发人员确定
	 * 	token 登录凭证 h5支付, 微信小程序需要
	 *
	 */
	openOrderPay (params, {callback}) {
		let {token, merchantNo, merchantOrderNo, appId,amount,signData, orderTitle, remark } = params
		this.openOrderPaySDK({
			merchantNo: merchantNo || '1',
			merchantOrderNo,
			token,
			signData:signData || '1',
			appId: appId || '1',
			orderTitle: orderTitle || '1',
			remark: remark || '1',
			amount
		}).then(res => {
			callback && callback(res)
		}).catch(err => {
			console.log(JSON.stringify(err, 'err'))
		})
	}

	/**
	 *  唤起登录
	 * @param {*} yshparams  原生sdk 所需参数
	 * {
	 * 		forceLogin: false, // 不强制唤起登录
	 * 		notCallLogin: true  // 不登录获取用户信息 false 登录
	 * 		latestUtm: true // 登录的时候 传入utm统计登录
	 * }
	 * @param {*} otherTypeParam 其他登录方式所需参数
	 * @param {String} tokenKey 存取token的key
	 */
	callAppLogin (yshparams = { forceLogin: false, notCallLogin: false,  latestUtm: '' }, otherTypeParam = {},tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.login({
					data: yshparams,
					success: (data) => {
						let token = ''
						let {msgCode, result} = data
						if (msgCode === 100) {
							if (typeof result === 'string') {
								const b = JSON.parse(result)
								token = b.token
							} else if (Object.keys(result).length === 0) {
								token = ''
							} else {
								token = result.token
							}
							window.localStorage.setItem(tokenKey, token)
							resolve(result)
						} else {
							reject(data)
						}
					}
				})
			})
		})
	}

	// loading
	showLoading () {
		setWeHotel(() => {
			WeSDK.openLoadingV({})
		})
	}
	hideLoading () {
		setWeHotel(() => {
			WeSDK.closeLoadingV({})
		})
	}

	// 打开小程序
	openMiniprogram (params) {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.miniprogram({
					data: params,
					success: (res) => {
						console.log(res.msgCode)
						if (res && res.msgCode === 200) {
							this.openBrowser(
								{ url: 'https://a.app.qq.com/o/simple.jsp?pkgname=com.tencent.mm&from=singlemessage' })
								reject(res)
						} else {
							resolve(res)
						}
					}
				})
			})
		})
	}

	refreshPage (callback) {
		if (this.refreshRegistered) {
			this.refreshPageCallbacks.push(callback)
		} else {
			setWeHotel(() => {
				this.refreshPageCallbacks.push(callback)
				this.refreshRegistered = true
				// 重复注册会用后一个回调覆盖前一个
				// 所以只注册一次
				WeSDK.registerHandler('BTPublicPlugin/refreshPage', () => {
					for (const func of this.refreshPageCallbacks) {
						if (typeof func === 'function') {
							func()
						}
					}
				})
			})
		}
  }

  // 页面将要展示
	viewWillAppear (callback) {
		if (this.viewWillAppearRegistered) {
			this.viewWillAppearCallbacks.push(callback)
		} else {
			setWeHotel(() => {
				this.viewWillAppearCallbacks.push(callback)
				this.viewWillAppearRegistered = true
				WeSDK.registerHandler('BTPublicPlugin/viewWillAppear', () => {
					for (const func of this.viewWillAppearCallbacks) {
						if (typeof func === 'function') {
							func()
						}
					}
				})
			})
		}
	}

	// 页面将要离开
	viewWillDisappear (callback) {
		if (this.viewWillDisappearRegistered) {
			this.viewWillDisappearCallbacks.push(callback)
		} else {
			setWeHotel(() => {
				this.viewWillDisappearCallbacks.push(callback)
				this.viewWillDisappearRegistered = true
				WeSDK.registerHandler('BTPublicPlugin/viewWillDisappear', () => {
					for (const func of this.viewWillDisappearCallbacks) {
						if (typeof func === 'function') {
							func()
						}
					}
				})
			})
		}
	}

	// 扫描护照
	openScanCard (params,tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.openScanCard({
					data: params || {},
					success: (data) => {
						let token = ''
						if (data.msgCode === 100) {
							if (typeof data.result === 'string') {
								const b = JSON.parse(data.result)
								token = b.token
							} else if (Object.keys(data.result).length === 0) {
								token = ''
							} else {
								token = data.result.token
							}
							window.localStorage.setItem(tokenKey, token)
							resolve(data.result)
						} else {
							reject(data)
						}
					}
				})
			})
		})
  }

  // 获取设备信息
  getClientInfo () {
    return new Promise((resolve) => {
      setWeHotel(() => {
        WeSDK.getClientInfo(({ msgCode, result }) => {
          if (+msgCode === 100) {
            resolve(result)
          } else {
            reject('设备信息获取失败')
          }
        })
      })
    })
  }

  openRouterPath (params) {
    return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.openRouterPath({
					data: params,
					success: (data) => {
						if (data.msgCode === 100) {
							resolve(data)
						} else {
							reject(data)
						}
					}
				})
			})
		})
  }

  openRouterPage (params) {
		return new Promise((resolve, reject) => {
			setWeHotel(() => {
				WeSDK.openRouterPage({
					data: params,
					success: (data) => {
						if (data.msgCode === 100) {
							resolve(data)
						} else {
							reject(data)
						}
					}
				})
			})
		})
  }

  // 打开视频
  openVideo (params, callback) {
		setWeHotel(() => {
			WeSDK.openVideo({
				data: params || {},
				success: (data) => {
          callback&&callback(data)
				}
			})
		})
	}

  // 打开酒店app原生优惠券页面
  openWehotelCoupons () {
		setWeHotel(() => {
			WeSDK.openWehotelCoupons({})
		})
	}
}

export { JinjiangOnlineSDK }

