/* eslint-disable */
import {
	CLIENT_TYPE_ANDROID,
	CLIENET_TYPE_IOS
} from './const'
import getAppType from './appType'
import getAppVersion, { getShortVersion } from './appversion'
import {
	androidWebViewJavascriptBridge,
	iOSWebViewJavascriptBridge
} from './javascriptBridge'
import native from './native'

// 全局暴露对象
var wehotelSDK = {}

// native是否对容器注入完成
wehotelSDK.state = false   //false

// 系统类型
wehotelSDK.clientType = getAppType()

// 调试模式
wehotelSDK.debug = wehotelSDK.clientType?false:true;
// 是否是Android客户端  boolean
wehotelSDK.isAndroid = wehotelSDK.clientType === CLIENT_TYPE_ANDROID
// 是否是iOS客户端   boolean
wehotelSDK.isIOS = wehotelSDK.clientType === CLIENET_TYPE_IOS
// 客户端版本号
// 锦江APP中读取锦江的版本号
// 铂涛旅行APP中读取铂涛旅行版本号
// 改版本号为对外版本号
// 1.0202
wehotelSDK.appVersion = getAppVersion()
// 1.2.2
wehotelSDK.shortAppVersion = getShortVersion()
// APP渠道类型
// 该类型包括 锦江APP， 铂涛旅行APP
// Jinjian / botao
// wehotelSDK.sourceType = getSourceType()

//区分改版前后   后：'wehotel'  前：''
// wehotelSDK.isWehotel = isWehotel();

//区分业务线
wehotelSDK.appkey = ''
// wehotelSDK.sign = ''
// wehotelSDK.timestamp = ''

//任务队列的数组
wehotelSDK.readyCallbackList = []

//native中的api列表
wehotelSDK.api = getApiArr(native)

//服务端获取的api列表
wehotelSDK.serviceApi = []

//初始化api指向空函数
wehotelSDK.noop = function () {}

//自定义函数
wehotelSDK.register = []

wehotelSDK.testArr = []

/**
 * 降级方案
 */
var demotion = {}

for (let i = 0, len = wehotelSDK.api.length; i < len; i++) {
  wehotelSDK[wehotelSDK.api[i].key] = wehotelSDK.noop;
}

/**
 * 初始化bridge注入
 * @param {function} callback
 */
function initWebViewBridge (callback) {
	if (wehotelSDK.debug) {
		callback()
	} else {
		switch (wehotelSDK.clientType) {
			case 'android':
				androidWebViewJavascriptBridge(callback)
				break
			case 'iOS':
				iOSWebViewJavascriptBridge(callback)
				break
		}
	}
}

function webViewBridgeCallback (bridge) {
	if (wehotelSDK.clientType === 'android' && !wehotelSDK.debug && bridge) {
		/**
		 * Android 客户端初始化
		 */
		bridge.init(function (message, responseCallback) {
			responseCallback()
		})
	}
	//bridge初始化之后初始化api函数
	if (!wehotelSDK.debug) {
		console.log('注册函数')
		for (let i = 0, len = wehotelSDK.api.length; i < len; i++) {
			wehotelSDK[wehotelSDK.api[i].key] = function (option) {
				let opt
				if (typeof option == 'function') {
					opt = {}
					opt.success = option
				} else {
					opt = option || {}
				}
				let data = opt.data || {},
					success = opt.success || wehotelSDK.noop

				bridge.callHandler(wehotelSDK.api[i].api, data, callHandlerCallback(success))

			}
		}
	}

	//初始化完成，执行自定义注册函数
	!wehotelSDK.debug && callRegister(bridge)

	//初始化完成，state= true；
	wehotelSDK.state = true;
	if (!wehotelSDK.debug) {
		getNativeApi()
	}else{
		callReady();
		callDemotion();
	}
}

//格式化回调函数中的data
function callHandlerCallback (callback) {
	return function (data) {
		if (typeof data === 'string') {
			data = JSON.parse(data)
		}
		callback(data)
	}
}

/*
 * 获取appKey
 * */
wehotelSDK.setAppKey = function (appKey) {
	if (!wehotelSDK.debug) {
		wehotelSDK.appkey = appKey;
		// wehotelSDK.sign = obj.sign;
		// wehotelSDK.timestamp = obj.timestamp;
		getNativeApi()
	}
}

wehotelSDK.ready = function (callback) {
	typeof callback === 'function' && wehotelSDK.readyCallbackList.push(callback);
	callReady();
}

wehotelSDK.init = function () {//非调试模式下进来之后自执行初始化
	if (!wehotelSDK.debug) {
		initWebViewBridge(webViewBridgeCallback)
	}
	if (wehotelSDK.debug && !wehotelSDK.state) {  //调试模式
		wehotelSDK.state = true
		initWebViewBridge(webViewBridgeCallback)
	}
}()

/*注册函数*/

/**
 *  @method registerHandler
 *  @param handleName 注册函数名
 *  @param callback 触发执行回调
 */
wehotelSDK.registerHandler = function (handleName, callback) {
	wehotelSDK.register.push({
		handleName: handleName,
		callback: callback
	})
	if (window.WebViewJavascriptBridge && wehotelSDK.state) {
		callRegister(WebViewJavascriptBridge)
	}
}

function callRegister (bridge) {
	if (wehotelSDK.state) {
		for (let i = 0, len = wehotelSDK.register.length; i < len; i++) {
			bridge.registerHandler(wehotelSDK.register[i].handleName, callRegisterCallback(wehotelSDK.register[i].callback))
		}
	} else {
		console.log(wehotelSDK.register)
	}
}

/**
 *  返回一个正确的register回调函数
 */
function callRegisterCallback (callback) {
	return function (data, responseCallback) {
		if (typeof data === 'string') {
			data = JSON.parse(data)
		}
		callback(data, responseCallback)
	}
}

function getApiArr (obj, key, arr) {
	var apiArr = arr || []
	if (typeof obj === 'string') {
		apiArr.push({key: key, api: obj})
	} else {
		Object.keys(obj).forEach(function (key) {
			getApiArr(obj[key], key, apiArr)
		})
	}
	return apiArr
}

function callReady () {
	// console.log('任务列表')
	if (wehotelSDK.state) {
		for (let i = 0, len = wehotelSDK.readyCallbackList.length; i < len; i++) {
			wehotelSDK.readyCallbackList[i].call(wehotelSDK)
		}
		wehotelSDK.readyCallbackList = []
	}
}

//获取appKey之后和bridge初始化完成之后都会执行这个方法
function getNativeApi () {
	console.log(wehotelSDK.debug + ',' + wehotelSDK.state + ',' + wehotelSDK.appkey)
	if (!wehotelSDK.debug && wehotelSDK.appkey && wehotelSDK.state) {
		wehotelSDK.getNativeApi({
			data: {JSID: wehotelSDK.appkey}, success: function (data) {
				data = data || {}
				if (data.msgCode == 100) {
					let result = data.result || ''
					wehotelSDK.serviceApi = result.split('&');
					// console.log('服务端api列表:')
					// console.log(wehotelSDK.serviceApi)
					//执行任务列表中的任务，并清空
					callReady()
				}
			}
		})
    wehotelSDK.registTitleControler(function (data) {
      if (data.msgCode == 100) {
        console.log('获取Android 标题返回键以及物理键权限成功');
      }
    })
	} else {

		console.log('没有初始化appkey或者处于debug模式或者bridge初始化未完成')
	}
}

function hasOwn (obj, key) {
	return hasOwnProperty.call(obj, key)
}

function callDemotion (handleName, callback) {
	if (handleName && callback) {
		wehotelSDK[handleName] = demotion[handleName] = callback;
	} else {
		for (let i = 0; i < wehotelSDK.api.length; i++) {
			if (hasOwn(demotion, wehotelSDK.api[i].key)) {
				wehotelSDK[wehotelSDK.api[i].key] = demotion[wehotelSDK.api[i]]
			} else {
				wehotelSDK[wehotelSDK.api[i].key] = function () {}
			}
		}
	}

}

/**
 * @method demotion 设置接口降级方案
 */
wehotelSDK.demotion = function (handleName, callback) {
	if (wehotelSDK.state) {
		demotion[handleName] = callback;
		callDemotion(handleName, callback)
	} else {
		demotion[handleName] = callback
	}

}


export default wehotelSDK
