import { CommonSDK } from './common'
import { asyncLoadJs } from '../utils/load'
import { getLocal, removeLocal } from '../utils/storage'
import { getQueryString } from '../utils/url-params'
import { MALL_URL } from '../utils/host'
import CryptoJS from '../utils/lib/crypto-js'
// asyncLoadJs('https://lf1-cdn-tos.bytegoofy.com/goofy/developer/jssdk/jssdk-1.0.3.js')

class ToutiaoSDK extends CommonSDK {
	static getInstance () {
		if (!this.instance) {
			this.instance = new ToutiaoSDK()
		}
		return this.instance
	}

	// 打开地图
	openRouterMap (params) {
		const latitude = params.lat
		const longitude = params.lng
		const content = params.chainName
		window.tt && window.tt.miniProgram.navigateTo({
			url: `/pages/loadMap/loadMap?latitude=${latitude}&longitude=${longitude}&content=${content}`
		})
	}

	gotoHomePage (url = '/project/home/views/home/index') {
		window.tt && window.tt.miniProgram.switchTab({
			url
		})
	}

	/**
	 * 打开新页面
	 * TODO 只实现URL跳转
	 * @param url
	 * @param isFitWindow
	 * @param isShowLoading
	 * @param isNeedBindNFCService
	 * @param gotoHome
	 */
	openNewWebView({ url, isFitWindow = true, isShowLoading = true, isNeedBindNFCService = false }, gotoHome) {
		if (url) {
			window.tt && window.tt.miniProgram.navigateTo({ url: `/project/home/views/webview/V2?url=${encodeURIComponent(url)}`})
		}
	}

	/**
	 * 支付
	 * @param {*} params 支付需要参数 接口返回
	 *  第二个参数对象为  自定义参数
	 *  callbackUrl 支付成功跳转地址 完整地址 https:xxx.xxx.xx/#/xx 非app
	 *  failBackUrl 支付失败 跳转页面 非app
	 *  orderTitle  支付订单类型
	 *  callback, remark 游上海sdk支付需要， 其他方式不需要
	 * 	wxSource 小程序 支付source 由小程序开发人员确定
	 * 	token 登录凭证 h5支付, 微信小程序需要
	 *
	 */
	openOrderPay (params, { callbackUrl = '', wxSource = 'JinJiangHotel', failBackUrl = '' }, tokenKey = 'token') {
		// 锦江酒店小程序支付
		let sParams = JSON.stringify(params)
		const newStr = CryptoJS.enc.Utf8.parse(sParams)
		const base = CryptoJS.enc.Base64.stringify(newStr)

		tt.miniProgram.navigateTo({
			url: "/project/pay/views/currencyCheckStand/currencyCheckStand?payPrams=" + base
		});
	}

	/**
	 * 唤起登录
	 * @param {*} yshparams  原生sdk 所需参数
	 * @param {*} otherTypeParam 其他登录方式所需参数
	 * @param {String} tokenKey 存取token的key
	 */
	callAppLogin (yshparams = {}, otherTypeParam = {}, tokenKey = 'token') {
		return new Promise((resolve, reject) => {
			const token = getLocal(tokenKey) || ''
			let { notCallLogin } = yshparams
			if (notCallLogin) {
				const oMember = {
					token: token
				}
				resolve(oMember)
			} else {
				// 锦江酒店小程序
				const operator = location.href.includes('?') ? '&' : '?'
				let url = `${window.location.href}${operator}login=1`
				tt.miniProgram.navigateTo({ url: `/project/home/views/webview/V2?url=${encodeURIComponent(url)}`})
			}
		})
	}
}

export { ToutiaoSDK }
