export const getScrollParent = (el, yAxis = true) => {
	const property = yAxis ? 'overflow-y' : 'overflow-x'
	const scrollState = getComputedStyle(el)[property]
	if ((scrollState === 'scroll' || scrollState === 'auto') && el !== document.body) {
		return el
	} else {
		if (el === document.documentElement || el === document.body) {
			return document
		} else {
			return getScrollParent(el.parentNode, yAxis)
		}
	}
}

let animationFrameId = null
let scrollCompleteTimer = null
/**
 * @description 平滑滚动
 * @param {Number} top 位置
 * @param {Number} duration 时长(ms)
 * @param {Number} minSpeed 最小速度(px/ms)
 * @returns {Promise} 动画完成
 */
export const smoothScroll = (top, duration = 300, minSpeed = 0.2) => {
	if (animationFrameId) {
		cancelAnimationFrame(animationFrameId)
		animationFrameId = null
	}
	if (scrollCompleteTimer) {
		clearTimeout(scrollCompleteTimer)
		scrollCompleteTimer = null
	}
	return new Promise(resolve => {
		const startTop = window.pageYOffset
		const change = top - startTop
		if (change !== 0) {
			const absChange = Math.abs(change)
			const avgSpeed = absChange / duration
			if (avgSpeed < minSpeed) {
				duration = Math.round(absChange / minSpeed)
			}
			let startTime = null
			const step = timeStamp => {
				if (!startTime) {
					startTime = timeStamp
					animationFrameId = requestAnimationFrame(step)
				} else {
					const timeChange = timeStamp - startTime
					if (timeChange > duration) {
						window.scrollTo(0, top)
						scrollCompleteTimer = setTimeout(resolve, 50)
						animationFrameId = null
					} else {
						const ratio = easeOutQuad(timeChange / duration)
						window.scrollTo(0, startTop + ratio * change)
						animationFrameId = requestAnimationFrame(step)
					}
				}
			}
			animationFrameId = requestAnimationFrame(step)
		}
	})
}
/**
 * @description 横向平滑滚动
 * @param {Element} element 滚动元素
 * @param {Number} left 位置
 * @param {Number} duration 时长(ms)
 * @param {Number} minSpeed 最小速度(px/ms)
 */
let horizontalAnimation = null
export const smoothScrollLeft = (element, left, duration = 300, minSpeed = 0.15) => {
	// 上一次动画没结束，触发新的动画
	// 则中止上一次动画
	if (horizontalAnimation) {
		cancelAnimationFrame(horizontalAnimation)
		horizontalAnimation = null
	}
	const startLeft = element.scrollLeft
	const change = left - startLeft
	if (change !== 0) {
		const absChange = Math.abs(change)
		const avgSpeed = absChange / duration
		if (avgSpeed < minSpeed) {
			duration = Math.round(absChange / minSpeed)
		}
		let startTime = null
		const step = timeStamp => {
			if (!startTime) {
				startTime = timeStamp
				horizontalAnimation = requestAnimationFrame(step)
			} else {
				const timeChange = timeStamp - startTime
				if (timeChange > duration) {
					element.scrollLeft = left
					horizontalAnimation = null
				} else {
					const ratio = easeOutQuad(timeChange / duration)
					element.scrollLeft = startLeft + ratio * change
					horizontalAnimation = requestAnimationFrame(step)
				}
			}
		}
		horizontalAnimation = requestAnimationFrame(step)
	}
}
function easeOutQuad (x) {
	return 1 - (1 - x) * (1 - x)
}