/**
 * 通过时间戳获取格式化日期
 * dateFormat(1590478470324, 'yyyy年mm月dd日 hh:MM:ss 星期w')  =>  2020年05月26日 15:34:30 星期二"
 * @param {*} timestamp
 * @param {*} fmt
 */
export const dateFormat = (timestamp, fmt) => {
        const D = new Date()
        const week = '日一二三四五六'
        timestamp && D.setTime(timestamp)
        fmt = fmt || 'yyyy-mm-dd'
        const d = {
            'm+': D.getMonth() + 1,
            'd+': D.getDate(),
            'w+': week.charAt(D.getDay()),
            'h+': D.getHours(),
            'M+': D.getMinutes(),
            's+': D.getSeconds()
        }
        if (/(y+)/.test(fmt)) {
            fmt = fmt.replace(RegExp.$1, (D.getFullYear() + '').slice(-RegExp.$1.length))
        }
        Object.keys(d).forEach((key) => {
            if (new RegExp(`(${key})`).test(fmt)) {
                fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1) ? d[key] : (`00${d[key]}`).slice(('' + d[key]).length))
            }
        })
        return fmt
    }
    /**
     * 秒数 转化成  x天x小时x分钟x秒
     * @param {*} value
     * @param {*} fmt
     * formatDuring(10000) => 2小时46分钟40秒
     */
export const formatDuring = (value = 0, fmt = ['天', '小时', '分钟', '秒']) => {
    let theTime = parseInt(value)// 需要转换的时间秒
    let theTime1 = 0// 分
    let theTime2 = 0// 小时
    let theTime3 = 0// 天
    if (theTime > 60) {
        theTime1 = parseInt(theTime / 60)
        theTime = parseInt(theTime % 60)
        if (theTime1 > 60) {
        theTime2 = parseInt(theTime1 / 60)
        theTime1 = parseInt(theTime1 % 60)
        if (theTime2 > 24) {
        // 大于24小时
        theTime3 = parseInt(theTime2 / 24)
        theTime2 = parseInt(theTime2 % 24)
        }
        }
    }
    let result = ''
    if (theTime > 0 && fmt[3]) {
        result = '' + parseInt(theTime) + fmt[3]
    }
    if (theTime1 > 0 && fmt[2]) {
        result = '' + parseInt(theTime1) + fmt[2] + result
    }
    if (theTime2 > 0 && fmt[1]) {
        result = '' + parseInt(theTime2) + fmt[1] + result
    }
    if (theTime3 > 0 && fmt[0]) {
        result = '' + parseInt(theTime3) + fmt[0] + result
    }
    return result
}