//
/**
 * 获取链接上的参数
 * @param {*} key 要获取的key
 * @param {*} url  目标url
 * @retruns value
 */
export const getParam
	= (key, url= location.href) => {
	let urlReg = new RegExp(`(?:&|\\?)${key}=(.*?)(?=&|$)`, 'g')
    let res = []
    let match
    match = urlReg.exec(url)
    while (match) {
        res.push(decodeURIComponent(match[1]))
        match = urlReg.exec(url)
    }
    // 如果有多个结果返回数组，否则直接返回获取的字符串
    return res.length > 1 ? res : res[0]
}
/**
 * 将json转化成 url参数
 * @param {*} obj // url要拼接的参数 {a:1, b:2} => a=1&b=2
 */
export const getQueryString = (obj) => {
	let keyList = Object.keys(obj)
	if (keyList.length) {
		let arr = Object.keys(obj).map(key => {
			return `${key}=${obj[key]}`
		})
		return arr.join('&')
	}
	return ''
}
/**
 * 向url中添加参数
 *  url = http:xxx/XXX/?a=1  setParams(url, a, 2) => http:xxx/XXX/?a=1
 * @param {*} url 要添加参数的url
 * @param {*} key 参数名
 * @param {*} val 参数值
 * @returns url
 */
export const setParams = (key, val,url) => {
	if (!getParam(key, url) && (val && val !== 'undefined')) {
		const oUrl = url.split('?')
		if (oUrl.length > 2) {
			url = `${oUrl[0]}?${key}=${val}${oUrl[1] ? '&' + oUrl[1] : ''}?${oUrl[2]}`
		} else {
			url = `${oUrl[0]}?${key}=${val}${oUrl[1] ? '&' + oUrl[1] : ''}`
		}
	}
	return url
}
/**
 * 向url中添加参数
 *  url = http:xxx/XXX/ 'a=1'
 * @param {*} url 要添加参数的url
 * @param {*} key 参数名
 * @param {*} val 参数值
 * @returns url
 */
 export const concatUrl = (url, query) => {
	 if (!query) {
		 return url
	 }
	 if (url.includes('?')) {
		 return `${url}&${query}`
	 } else {
		return `${url}?${query}`
	 }
 }
